@@ -31,9 +31,7 @@ with "commands".
 "episode_start" marks the beginning of an episode.  
 
     """.strip(),
-    inputs={
-        "observations": Any, "seed": int, "get_commands": GetCommands, "episode_start": EpisodeStart,
-    },
+    inputs={"observations": Any, "seed": int, "get_commands": GetCommands, "episode_start": EpisodeStart,},
     outputs={"commands": Any},
     language="""
             in:seed? ;
